import pandas as pd
class FindType:
    def __init__(self, df):
        self.data = df
        self.columns = list(df.columns)

    def _possibles(self):
        return self.data.applymap(lambda x: type(x))

    def _unique_types(self, type_data):
        self.unique_list = []
        for column in self.columns:
            self.unique_list += list(set((type_data[column].values)))
        self.unique_list = list(set(self.unique_list))

    def type_analysis(self, perc=True):
        a = pd.DataFrame(columns=self.columns)
        types = self._possibles()
        self._unique_types(types)
        a['Type'] = self.unique_list
        for i in range(len(self.unique_list)):
            for column in self.columns:
                a.loc[i, column] = (len(types[types[column] == self.unique_list[i]]) / len(types)) * 100
        return a.set_index(['Type'])


from setuptools import setup, find_packages

VERSION = '0.0.12'
DESCRIPTION = 'Type Analysis tool for Pandas DataFrames'
LONG_DESCRIPTION = 'A package that helps data analysts, engineers, and scientists to efficiently identify the data type distribution in a pandas dataframe'

# Setting up
setup(
    name="typalizer",
    version=VERSION,
    author="Mursil Khan",
    author_email="<mursilkhan30@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['pandas'],
    keywords=['python', 'data', 'analysis', 'type analysis', 'pandas', 'dataframes'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)